import 'package:clean_network/clean_network.dart';
import 'package:freezed_annotation/freezed_annotation.dart';

part 'app_error.freezed.dart';

@freezed
class AppError with _$AppError {
  const AppError._();
  const factory AppError.server({required String message}) = _AppError;
  const factory AppError.network({required String message}) = _NetworkError;

  /// Convert [ApiException] to [AppError]
  factory AppError.fromApiException(ApiException exception) {
    return exception.when(
      server: (message, _) => AppError.server(message: message),
      network: (_) => const AppError.network(message: 'Network Error'),
      unknown: (message, _) => AppError.server(message: message),
      parse: (message, _) => AppError.server(message: message),
      unauthorized: (message, _) => AppError.server(message: message),
      timeout: (message, _) => AppError.server(message: message),
      validation: (message, _, __) => AppError.server(message: message),
    );
  }
}
