import 'package:freezed_annotation/freezed_annotation.dart';

part 'paginated_clean_state.freezed.dart';

/// {@template paginated_clean_state}
/// Base state for paginated_clean_bloc
/// {@endtemplate}
@Freezed(map: FreezedMapOptions.none, genericArgumentFactories: true)
sealed class PaginatedCleanState<T, E> with _$PaginatedCleanState<T, E> {
  /// {@macro paginated_clean_state}
  /// PaginatedInitial state
  const factory PaginatedCleanState.initial() = PaginatedCleanInitial<T, E>;

  /// {@macro paginated_clean_state}
  /// PaginatedLoading state
  const factory PaginatedCleanState.loading() = PaginatedCleanLoading<T, E>;

  /// {@macro paginated_clean_state}
  /// PaginatedError state
  const factory PaginatedCleanState.error({
    required E error,
  }) = PaginatedCleanError<T, E>;

  /// {@macro paginated_clean_state}
  /// PaginatedSuccess state
  const factory PaginatedCleanState.success({
    required List<T> data,
    @Default(false) bool isLoadingMore,
  }) = PaginatedCleanSuccess<T, E>;
}
